@@ -8,4 +8,4 @@ class OptionalSlashRouter(DefaultRouter):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.trailing_slash = '/?'
+        self.trailing_slash = "/?"
